@@ -42,7 +42,7 @@ KLettresView::KLettresView(KLettres *parent)
     m_klettres = parent;
 
     //lineEdit for user input
-    m_letterEdit = new KLineEdit( this );
+    m_letterEdit = new QLineEdit( this );
     m_letterEdit->setToolTip(i18n("Type the letter or syllable that you just heard" ) );
     m_letterEdit->setFont(Prefs::font());
     m_letterEdit->setContextMenuPolicy(Qt::NoContextMenu);
@@ -156,7 +156,7 @@ void KLettresView::game()
     m_cursorPos = 1;
     //reset everything so when you change language or levels
     //it all restarts nicely
-    QObject::disconnect(m_letterEdit, &KLineEdit::textChanged, this, &KLettresView::slotProcess);
+    QObject::disconnect(m_letterEdit, &QLineEdit::textChanged, this, &KLettresView::slotProcess);
     m_letterEdit->clear();
     m_letterEdit->setCursorPosition(0);
     m_letterEdit->setMaxLength( 1 );
@@ -164,24 +164,24 @@ void KLettresView::game()
     m_upperLetter.clear();
     chooseSound();
     randomInt++;
-    QObject::connect(m_letterEdit, &KLineEdit::textChanged, this, &KLettresView::slotProcess);
+    QObject::connect(m_letterEdit, &QLineEdit::textChanged, this, &KLettresView::slotProcess);
 }
 
 void KLettresView::slotProcess(const QString &inputLetter)
 {
     QString lang = Prefs::language();
-    QObject::disconnect(m_letterEdit, &KLineEdit::textChanged, this, &KLettresView::slotProcess);
+    QObject::disconnect(m_letterEdit, &QLineEdit::textChanged, this, &KLettresView::slotProcess);
 
     //check if backspace
     if (inputLetter.length() != m_cursorPos) {
         m_cursorPos--;
         m_letterEdit->setMaxLength( m_cursorPos );
-        QObject::connect(m_letterEdit, &KLineEdit::textChanged, this, &KLettresView::slotProcess);
+        QObject::connect(m_letterEdit, &QLineEdit::textChanged, this, &KLettresView::slotProcess);
         return;
     }
     QChar input_character = inputLetter.at(inputLetter.length()-1);
     QChar input_character_u; 
-    qCDebug(KLETTRES_LOG) << "input_character " << input_character << endl;
+    qCDebug(KLETTRES_LOG) << "input_character " << input_character;
     
     if ((!LangUtils::isIndian(lang) && (input_character.isLetter())) || (LangUtils::isIndian(lang)))                               
     {
@@ -196,9 +196,9 @@ void KLettresView::slotProcess(const QString &inputLetter)
         m_letterEdit->setText(m_upperLetter);
         QTimer::singleShot(m_timer*100, this, &KLettresView::slotTimerDone);
     }  else {
-        qCDebug(KLETTRES_LOG) << "cursor " << m_cursorPos << endl;
+        qCDebug(KLETTRES_LOG) << "cursor " << m_cursorPos;
         m_letterEdit->backspace();
-        QObject::connect(m_letterEdit, &KLineEdit::textChanged, this, &KLettresView::slotProcess);
+        QObject::connect(m_letterEdit, &QLineEdit::textChanged, this, &KLettresView::slotProcess);
     }
     
 }
@@ -206,8 +206,8 @@ void KLettresView::slotProcess(const QString &inputLetter)
 void KLettresView::slotTimerDone()
 {
     QString match = m_currentLetter.left(m_cursorPos );
-    qCDebug(KLETTRES_LOG) << "match " << match.toUpper() << endl;
-    qCDebug(KLETTRES_LOG) << "m_upperLetter " << m_upperLetter << endl;
+    qCDebug(KLETTRES_LOG) << "match " << match.toUpper();
+    qCDebug(KLETTRES_LOG) << "m_upperLetter " << m_upperLetter;
     
     if (match == m_upperLetter) {
         if (m_cursorPos!=m_length) {//if text in lineEdit not equal to text on button
@@ -216,18 +216,18 @@ void KLettresView::slotTimerDone()
             m_letterEdit->setCursorPosition( m_cursorPos );
             m_letterEdit->setFocus();
             m_cursorPos ++;
-            QObject::connect(m_letterEdit, &KLineEdit::textChanged, this, &KLettresView::slotProcess);
+            QObject::connect(m_letterEdit, &QLineEdit::textChanged, this, &KLettresView::slotProcess);
         } else {
             game();  //another syllable
         }
     } else { //if not, cut it
-        qCDebug(KLETTRES_LOG) << "wrong letter "<< endl;
+        qCDebug(KLETTRES_LOG) << "wrong letter ";
         m_letterEdit->backspace();  //delete the char to the left  and position curseur accordingly
         m_upperLetter.remove(m_upperLetter.size()-1, 1);
         m_letterEdit->setFocus();
         //play sound again
         m_klettres->soundFactory->playSound(m_random);
-        QObject::connect(m_letterEdit, &KLineEdit::textChanged, this, &KLettresView::slotProcess);
+        QObject::connect(m_letterEdit, &QLineEdit::textChanged, this, &KLettresView::slotProcess);
     }
 }
 
